==> monica-3.7.0p0.tgz: www/monica/resources/lang/he/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => 'תזכורת עבור :contact',
    'greetings' => 'היי :username',
    'want_reminded_of' => 'רצית שאזכיר לך את :reason',
    'for' => 'עבור: :name',
    'comment' => 'הערה: :comment',
    'footer_contact_info' => 'הוספה, צפייה, השלמה ושינוי מידע על איש הקשר הזה:',
    'footer_contact_info2' => 'הצגת הפרופיל של :profile',
    'footer_contact_info2_link' => 'הצגת הפרופיל של :name‏ :url',

    'notification_subject_line' => 'יש לך אירוע קרב',
    'notification_description' => 'בעוד :count ימים (ב־:date), יתרחש האירוע הבא:',

    'stay_in_touch_subject_line' => 'לשמור על קשר עם :name',
    'stay_in_touch_subject_description' => '{1}ביקשת לקבל תזכורת ליצור קשר עם :name כל יום.|{2}ביקשת לקבל תזכורת ליצור קשר עם :name כל יומיים.|{3,n}ביקשת לקבל תזכורת ליצור קשר עם :name כל :frequency ימים.',

    'notifications_whoops' => 'אופס!',
    'notifications_hello' => 'שלום!',
    'notifications_regards' => 'בברכה',
    'notifications_footer' => 'אם נתקלת בבעיה בלחיצה על הכפתור „:actionText”, יש להעתיק ולהדביק את הכתובת שלהלן לתוך הדפדפן שלך: [:actionURL](:actionURL)',
    'notifications_rights' => 'כל הזכויות שמורות',

    'confirmation_email_title' => 'מוניקה – אימות דוא״ל',
    'confirmation_email_intro'=> 'כדי לאמת את כתובת הדוא״ל שלך נא ללחוץ על הכפתור שלהלן',
    'confirmation_email_button' => 'אימות כתובת דוא״ל',
    'confirmation_email_bottom' => 'אם לא יצרת חשבון, לא נדרשות פעולות נוספות.',

    'password_reset_title' => 'מוניקה - התראת איפוס ססמה',
    'password_reset_intro' => 'הודעה זו נשלחה אליך כי התקבלה בקשה לאיפוס הססמה בחשבונך.',
    'password_reset_button' => 'איפוס ססמה',
    'password_reset_expiration' => 'קישור זה לאיפוס הססמה יפוג בעוד :count דקות.',
    'password_reset_bottom' => 'אם לא ביקשת לאפס את הססמה, לא נדרשות פעולות נוספות.',

    'invitation_title' => 'מוניקה – קיבלת הזמנה מאת :name',
    'invitation_intro' => 'הוזמנת על ידי :name (:email) להשתמש במוניקה, כלי נחמד לניהול קשרים אישיים.',
    'invitation_link' => 'כדי לקבל את ההזמנה, יש ללחוץ על הקישור להלן:',
    'invitation_button' => 'קבלת ההזמנה',
    'invitation_expiration' => 'הקישור יפוג תוך :count ימים.',

    'export_title' => 'Your export is ready',
    'export_description' => 'You requested a data export on :date. It is now ready to download.',
    'export_download' => 'Download export',

];

==> monica-4.0.0.tgz: www/monica/resources/lang/he/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => 'תזכורת עבור :contact',
    'greetings' => 'היי :username',
    'want_reminded_of' => 'רצית שאזכיר לך את :reason',
    'for' => 'עבור: :name',
    'comment' => 'הערה: :comment',
    'footer_contact_info' => 'הוספה, צפייה, השלמה ושינוי מידע על איש הקשר הזה:',
    'footer_contact_info2' => 'הצגת הפרופיל של :profile',
    'footer_contact_info2_link' => 'הצגת הפרופיל של :name‏ :url',

    'notification_subject_line' => 'יש לך אירוע קרב',
    'notification_description' => 'בעוד :count ימים (ב־:date), יתרחש האירוע הבא:',

    'stay_in_touch_subject_line' => 'לשמור על קשר עם :name',
    'stay_in_touch_subject_description' => '{1}ביקשת לקבל תזכורת ליצור קשר עם :name כל יום.|{2}ביקשת לקבל תזכורת ליצור קשר עם :name כל יומיים.|{3,n}ביקשת לקבל תזכורת ליצור קשר עם :name כל :frequency ימים.',

    'notifications_whoops' => 'אופס!',
    'notifications_hello' => 'שלום!',
    'notifications_regards' => 'בברכה',
    'notifications_footer' => 'אם נתקלת בבעיה בלחיצה על הכפתור „:actionText”, יש להעתיק ולהדביק את הכתובת שלהלן לתוך הדפדפן שלך: [:actionURL](:actionURL)',
    'notifications_rights' => 'כל הזכויות שמורות',

    'confirmation_email_title' => 'מוניקה – אימות דוא״ל',
    'confirmation_email_intro'=> 'כדי לאמת את כתובת הדוא״ל שלך נא ללחוץ על הכפתור שלהלן',
    'confirmation_email_button' => 'אימות כתובת דוא״ל',
    'confirmation_email_bottom' => 'אם לא יצרת חשבון, לא נדרשות פעולות נוספות.',

    'password_reset_title' => 'מוניקה - התראת איפוס ססמה',
    'password_reset_intro' => 'הודעה זו נשלחה אליך כי התקבלה בקשה לאיפוס הססמה בחשבונך.',
    'password_reset_button' => 'איפוס ססמה',
    'password_reset_expiration' => 'קישור זה לאיפוס הססמה יפוג בעוד :count דקות.',
    'password_reset_bottom' => 'אם לא ביקשת לאפס את הססמה, לא נדרשות פעולות נוספות.',

    'invitation_title' => 'מוניקה – קיבלת הזמנה מאת :name',
    'invitation_intro' => 'הוזמנת על ידי :name (:email) להשתמש במוניקה, כלי נחמד לניהול קשרים אישיים.',
    'invitation_link' => 'כדי לקבל את ההזמנה, יש ללחוץ על הקישור להלן:',
    'invitation_button' => 'קבלת ההזמנה',
    'invitation_expiration' => 'הקישור יפוג תוך :count ימים.',

    'export_title' => 'הייצוא שלך מוכן',
    'export_description' => 'ביקשת ייצוא נתונים ב־:date. הוא מוכן כעת להורדה.',
    'export_download' => 'הורדת הייצוא',

];
